@@ -83,6 +83,7 @@ def _set_options(bond, new_options, current_options):
 
 
 def _set_untouched_options_to_defaults(bond, mode, options, current_options):
+    mode = numerize_bond_mode(mode)
     for key, value in six.iteritems(getDefaultBondingOptions(mode)):
         if (key != 'mode' and key not in options and key in current_options):
             v = value[-1] if value else ''
@@ -203,3 +204,8 @@ def getAllDefaultBondingOptions():
     """
     with open(BONDING_DEFAULTS) as defaults:
         return json.loads(defaults.read())
+
+
+def numerize_bond_mode(mode):
+    return (mode if mode in BONDING_MODES_NUMBER_TO_NAME else
+            BONDING_MODES_NAME_TO_NUMBER[mode])
