@@ -30,20 +30,30 @@ import tempfile
 import threading
 
 from contextlib import contextmanager, closing
+from monkeypatch import MonkeyPatch
 from testlib import VdsmTestCase as TestCaseBase
 from testlib import mock
 from nose.plugins.skip import SkipTest
-try:
+from vdsm import utils
+from vdsm import concurrent
+from vdsm.commands import execCmd
+from vdsm.config import config
+from vdsm.protocoldetector import MultiProtocolAcceptor
+from yajsonrpc.betterAsyncore import Reactor
+
+if config.get('vars', 'ssl_implementation') == 'm2c':
     from vdsm.m2cutils import VerifyingSafeTransport
     from integration.m2chelper import TestServer, \
         get_server_socket, KEY_FILE, \
-        CRT_FILE, OTHER_KEY_FILE, OTHER_CRT_FILE
+        CRT_FILE, OTHER_KEY_FILE, OTHER_CRT_FILE, \
+        CLIENT_PROTOCOL, SSLContext
     _m2cEnabled = True
-except ImportError:
+else:
     from vdsm.sslutils import VerifyingSafeTransport
     from integration.sslhelper import TestServer, \
         get_server_socket, KEY_FILE, \
-        CRT_FILE, OTHER_KEY_FILE, OTHER_CRT_FILE
+        CRT_FILE, OTHER_KEY_FILE, OTHER_CRT_FILE, \
+        CLIENT_PROTOCOL, SSLContext
     _m2cEnabled = False
 from vdsm.sslutils import SSLHandshakeDispatcher
 
@@ -398,6 +408,85 @@ class CompareNameTest(TestCaseBase):
             '::ffff:127.0.0.1', 'example.com'))
 
 
+class TlsProtocolTest(TestCaseBase):
+
+    def test_sslv2(self):
+        with(self.listen()) as (host, port):
+            self.assertEqual(self.run_client(host, port, '-ssl2'), 1)
+
+    def test_sslv3(self):
+        with(self.listen()) as (host, port):
+            self.assertEqual(self.run_client(host, port, '-ssl3'), 1)
+
+    def test_tlsv1(self):
+        with(self.listen()) as (host, port):
+            self.assertEqual(self.run_client(host, port, '-tls1'), 0)
+
+    def test_tlsv11(self):
+        with(self.listen()) as (host, port):
+            self.assertEqual(self.run_client(host, port, '-tls1_1'), 0)
+
+    def test_tlsv12(self):
+        with(self.listen()) as (host, port):
+            self.assertEqual(self.run_client(host, port, '-tls1_2'), 0)
+
+    def test_client_tlsv1(self):
+        with(self.listen()) as (host, port):
+            self.use_client(host, port, CLIENT_PROTOCOL)
+
+    def test_client_tlsv12(self):
+        if _m2cEnabled:
+            raise SkipTest('Setting TLSv1_2 protocol exclusively is not '
+                           'possible with m2c')
+
+        with self.assertRaises(ssl.SSLError) as ssle:
+            with(self.listen(ssl.OP_NO_TLSv1_1 | ssl.OP_NO_TLSv1_2)) \
+                    as (host, port):
+                self.use_client(host, port, ssl.PROTOCOL_TLSv1_2)
+
+        # WRONG_VERSION_NUMBER
+        self.assertEqual(ssle.exception.errno, 1)
+
+    @contextmanager
+    @MonkeyPatch(MultiProtocolAcceptor, '_register_protocol_detector',
+                 lambda d: d.close())
+    def listen(self, excludes=0, protocol=CLIENT_PROTOCOL):
+        reactor = Reactor()
+
+        sslctx = SSLContext(cert_file=CRT_FILE, key_file=KEY_FILE,
+                            ca_certs=CRT_FILE, excludes=excludes,
+                            protocol=protocol)
+
+        acceptor = MultiProtocolAcceptor(
+            reactor,
+            socket.gethostname(),
+            0,
+            sslctx=sslctx
+        )
+
+        try:
+            t = concurrent.thread(reactor.process_requests)
+            t.start()
+            yield self.get_address(acceptor)
+        finally:
+            acceptor.stop()
+            t.join()
+
+    def get_address(self, acceptor):
+        return acceptor._acceptor.socket.getsockname()[0:2]
+
+    def run_client(self, host, port, protocol):
+        cmd = ['openssl', 's_client', '-connect', '%s:%s' % (host, port),
+               '-CAfile', CRT_FILE, '-cert', CRT_FILE, '-key', KEY_FILE,
+               protocol]
+        rc, _, _ = execCmd(cmd)
+        return rc
+
+    def use_client(self, host, port, protocol):
+        sslctx = SSLContext(cert_file=CRT_FILE, key_file=KEY_FILE,
+                            ca_certs=CRT_FILE, protocol=protocol)
+        utils.create_connected_socket(host, port, sslctx=sslctx)
+
 # The address of the tests server:
 ADDRESS = ("127.0.0.1", 8443)
 
