@@ -95,8 +95,9 @@ class Drive(core.Base):
                  'propagateErrors', 'address', 'apparentsize', 'volumeInfo',
                  'index', 'name', 'optional', 'shared', 'truesize',
                  'volumeChain', 'baseVolumeID', 'serial', 'reqsize', 'cache',
-                 'extSharedState', 'drv', 'sgio', 'GUID', 'diskReplicate',
-                 '_diskType', 'hosts', 'protocol', 'auth', 'discard')
+                 '_blockDev', 'extSharedState', 'drv', 'sgio', 'GUID',
+                 'diskReplicate', '_diskType', 'hosts', 'protocol', 'auth',
+                 'discard')
     VOLWM_CHUNK_SIZE = (config.getint('irs', 'volume_utilization_chunk_mb') *
                         constants.MEGAB)
     VOLWM_FREE_PCT = 100 - config.getint('irs', 'volume_utilization_percent')
@@ -194,12 +195,8 @@ class Drive(core.Base):
     def __init__(self, conf, log, **kwargs):
         if not kwargs.get('serial'):
             self.serial = kwargs.get('imageID'[-20:]) or ''
-        self._diskType = None
-        # device needs to be initialized in prior
-        # cause diskType setter uses self.device
-        # in diskType validation
-        self.device = kwargs.get('device', 'disk')
         super(Drive, self).__init__(conf, log, **kwargs)
+        self.device = getattr(self, 'device', 'disk')
         # Keep sizes as int
         self.reqsize = int(kwargs.get('reqsize', '0'))  # Backward compatible
         self.truesize = int(kwargs.get('truesize', '0'))
@@ -208,12 +205,7 @@ class Drive(core.Base):
         self.cache = config.get('vars', 'qemu_drive_cache')
         self.discard = kwargs.get('discard', False)
 
-        if self._diskType is None:
-            if (self.device in ("cdrom", "floppy") or not
-                    utils.isBlockDevice(self.path)):
-                self.diskType = DISK_TYPE.FILE
-            else:
-                self.diskType = DISK_TYPE.BLOCK
+        self._blockDev = None  # Lazy initialized
 
         self._customize()
         self._setExtSharedState()
@@ -318,7 +310,7 @@ class Drive(core.Base):
         Drive.volExtensionChunk is used to detect if a drive should be
         extended, and getNextVolumeSize to find the new size.
         """
-        return self._diskType == DISK_TYPE.BLOCK and self.format == "cow"
+        return self.blockDev and self.format == "cow"
 
     @property
     def replicaChunked(self):
@@ -332,11 +324,20 @@ class Drive(core.Base):
 
     @property
     def networkDev(self):
-        return self._diskType == DISK_TYPE.NETWORK
+        return getattr(self, '_diskType', None) == DISK_TYPE.NETWORK
 
     @property
     def blockDev(self):
-        return self._diskType == DISK_TYPE.BLOCK
+        if self._blockDev is None:
+            if self.networkDev or self.device in ("cdrom", "floppy"):
+                self._blockDev = False
+            else:
+                try:
+                    self._blockDev = utils.isBlockDevice(self.path)
+                except Exception:
+                    self.log.debug("Unable to determine if the path '%s' is a "
+                                   "block device", self.path, exc_info=True)
+        return self._blockDev
 
     @property
     def path(self):
@@ -347,25 +348,22 @@ class Drive(core.Base):
         if hasattr(self, "_path") and self._path != path:
             self.log.debug("Drive %s moved from %r to %r",
                            self.name, self._path, path)
+            # After live storage migration domain type may have changed
+            # invalidating cached blockDev.
+            self._blockDev = None
         self._path = path
 
     @property
     def diskType(self):
-        return self._diskType
+        if self.blockDev:
+            return DISK_TYPE.BLOCK
+        elif self.networkDev:
+            return DISK_TYPE.NETWORK
+        else:
+            return DISK_TYPE.FILE
 
     @diskType.setter
     def diskType(self, value):
-        if value not in SOURCE_ATTR:
-            raise exception.UnsupportedOperation(
-                "Unsupported diskType %r" % value)
-        if self.device in ['cdrom', 'floppy'] and value != DISK_TYPE.FILE:
-            raise exception.UnsupportedOperation(
-                "diskType of %r can only be 'file'" % self.device)
-
-        if self._diskType is not None and self._diskType != value:
-            self.log.debug("Drive %s type changed from %r to %r",
-                           self.name, self._diskType, value)
-
         self._diskType = value
 
     @property
